/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */

/* ***** BEGIN LICENSE BLOCK *****

 * Version: NPL 1.1/GPL 2.0/LGPL 2.1

 *

 * The contents of this file are subject to the Netscape Public License

 * Version 1.1 (the "License"); you may not use this file except in

 * compliance with the License. You may obtain a copy of the License at

 * http://www.mozilla.org/NPL/

 *

 * Software distributed under the License is distributed on an "AS IS" basis,

 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License

 * for the specific language governing rights and limitations under the

 * License.

 *

 * The Original Code is mozilla.org code.

 *

 * The Initial Developer of the Original Code is 

 * Netscape Communications Corporation.

 * Portions created by the Initial Developer are Copyright (C) 1998

 * the Initial Developer. All Rights Reserved.

 *

 * Contributor(s):

 *

 * Alternatively, the contents of this file may be used under the terms of

 * either the GNU General Public License Version 2 or later (the "GPL"), or 

 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),

 * in which case the provisions of the GPL or the LGPL are applicable instead

 * of those above. If you wish to allow use of your version of this file only

 * under the terms of either the GPL or the LGPL, and not to allow others to

 * use your version of this file under the terms of the NPL, indicate your

 * decision by deleting the provisions above and replace them with the notice

 * and other provisions required by the GPL or the LGPL. If you do not delete

 * the provisions above, a recipient may use your version of this file under

 * the terms of any one of the NPL, the GPL or the LGPL.

 *

 * ***** END LICENSE BLOCK ***** */



// SYNTAX HINTS:  dashes are delimiters.  Use underscores instead.

//  The first character after a period must be alphabetic.



pref("startup.homepage_override_url","chrome://navigator-region/locale/region.properties");

pref("browser.chromeURL","chrome://navigator/content/navigator.xul");



pref("network.search.url","http://cgi.netscape.com/cgi-bin/url_search.cgi?search=");



pref("keyword.URL", "http://keyword.netscape.com/keyword/");

pref("keyword.enabled", false);

pref("general.useragent.locale", "chrome://navigator/locale/navigator.properties");

pref("general.useragent.contentlocale", "chrome://navigator-region/locale/region.properties");

pref("general.useragent.misc", "rv:1.5");



pref("general.startup.browser",             true);

pref("general.startup.mail",                false);

pref("general.startup.news",                false);

pref("general.startup.editor",              false);

pref("general.startup.compose",             false);

pref("general.startup.addressbook",         false);



pref("general.open_location.last_url",      "");

pref("general.open_location.last_window_choice", 0);



pref("backups.number_of_prefs_copies", 1);



// 0 = blank, 1 = home (browser.startup.homepage), 2 = last

pref("browser.startup.page",                1);

pref("browser.startup.homepage",	   "chrome://navigator-region/locale/region.properties");

pref("browser.startup.homepage.count", 1);

// "browser.startup.homepage_override" was for 4.x

pref("browser.startup.homepage_override.1", true);

pref("browser.startup.autoload_homepage",   true);



pref("browser.cache.enable",                true); // see also network.http.use-cache

pref("browser.cache.disk.enable",           true);

pref("browser.cache.disk.capacity",         51200);

pref("browser.cache.memory.enable",         true);

//pref("browser.cache.memory.capacity",     -1);

// -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes

pref("browser.cache.disk_cache_ssl",        false);

// 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically

pref("browser.cache.check_doc_frequency",   3);



pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always

pref("browser.display.use_document_colors", true);

pref("browser.display.use_system_colors",   false);

pref("browser.display.foreground_color",    "#000000");

pref("browser.display.background_color",    "#FFFFFF");

pref("browser.display.force_inline_alttext", false); // true = force ALT text for missing images to be layed out inline

// 0 = no external leading, 

// 1 = use external leading only when font provides, 

// 2 = add extra leading both internal leading and external leading are zero

pref("browser.display.normal_lineheight_calc_control", 2);

pref("browser.display.show_image_placeholders", true); // true = show image placeholders while image is loaded and when image is broken

pref("browser.anchor_color",                "#0000EE");

pref("browser.visited_color",               "#551A8B");

pref("browser.underline_anchors",           true);

pref("browser.blink_allowed",               true);

pref("browser.enable_automatic_image_resizing", false);



pref("browser.display.use_focus_colors",    false);

pref("browser.display.focus_background_color", "#117722");

pref("browser.display.focus_text_color",     "#ffffff");

pref("browser.display.focus_ring_width",     1);

pref("browser.display.focus_ring_on_anything", false);



pref("browser.urlbar.autoFill", false);

pref("browser.urlbar.showPopup", true);

pref("browser.urlbar.showSearch", true);

pref("browser.urlbar.matchOnlyTyped", false);



pref("browser.chrome.site_icons", true);

pref("browser.chrome.favicons", false);



pref("browser.chrome.toolbar_tips",         true);

// 0 = Pictures Only, 1 = Text Only, 2 = Pictures and Text

pref("browser.chrome.toolbar_style",        2);



pref("browser.toolbars.showbutton.bookmarks", true);

pref("browser.toolbars.showbutton.go",      false);

pref("browser.toolbars.showbutton.home",    true);

pref("browser.toolbars.showbutton.print",   true);

pref("browser.toolbars.showbutton.search",  true);



pref("browser.turbo.enabled", false);



pref("browser.helperApps.alwaysAsk.force",  false);

pref("browser.helperApps.neverAsk.saveToDisk", "");

pref("browser.helperApps.neverAsk.openFile", "");



pref("accessibility.browsewithcaret", false);

pref("accessibility.warn_on_browsewithcaret", true);

// Tab focus model bit field:

// 1 focuses text controls, 2 focuses other form elements, 4 adds links.

// Most users will want 1, 3, or 7.

pref("accessibility.tabfocus", 7);

pref("accessibility.usetexttospeech", "");

pref("accessibility.usebrailledisplay", "");

pref("accessibility.accesskeycausesactivation", true);



// Type Ahead Find

pref("accessibility.typeaheadfind", true);

pref("accessibility.typeaheadfind.autostart", true);

pref("accessibility.typeaheadfind.linksonly", true);

pref("accessibility.typeaheadfind.startlinksonly", false);

pref("accessibility.typeaheadfind.timeout", 4000);

pref("accessibility.typeaheadfind.enabletimeout", true);

pref("accessibility.typeaheadfind.soundURL", "default");

pref("accessibility.typeaheadfind.enablesound", true);



// Dialog modality issues

pref("browser.prefWindowModal", true);

pref("browser.show_about_as_stupid_modal_window", false);



pref("browser.download.progressDnldDialog.keepAlive", true); // keep the dnload progress dialog up after dnload is complete

pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", true);

pref("browser.download.progressDnlgDialog.dontAskForLaunch", false);



// various default search settings

pref("browser.search.defaulturl", "chrome://navigator-region/locale/region.properties");

pref("browser.search.opensidebarsearchpanel", true);

pref("browser.search.last_search_category", "NC:SearchCategory?category=urn:search:category:1");

pref("browser.search.mode", 0);

pref("browser.search.powermode", 0);

// basic search popup constraint: minimum sherlock plugin version displayed

// (note: must be a string representation of a float or it'll default to 0.0)

pref("browser.search.basic.min_ver", "0.0");

pref("browser.urlbar.autocomplete.enabled", true);

pref("browser.urlbar.clickSelectsAll", true);

// when clickSelectsAll=true, does it also apply when the click is past end of text?

pref("browser.urlbar.clickAtEndSelects", true);



pref("browser.history_expire_days", 9);

pref("browser.history.grouping", "day");

pref("browser.sessionhistory.max_entries", 50);



// Translation service

pref("browser.translation.service", "http://www.teletranslator.com:8120/?AlisUI=frames_ex/moz_home&alis_info=moz&AlisTargetURI=");

pref("browser.translation.serviceDomain", "teletranslator.com");

  

// Platform for Internet Content Selection

pref("browser.PICS.ratings_enabled", false);

pref("browser.PICS.pages_must_be_rated", false);

pref("browser.PICS.disable_for_this_session", false);

pref("browser.PICS.reenable_for_this_session", false);

pref("browser.PICS.service.http___home_netscape_com_default_rating.service_enabled", true);

pref("browser.PICS.service.http___home_netscape_com_default_rating.s", 0);



// loading and rendering of framesets and iframes

pref("browser.frames.enabled", true);



// form submission

pref("browser.forms.submit.backwards_compatible", true);



// Tab browser preferences.

pref("browser.tabs.autoHide", true);

pref("browser.tabs.forceHide", false);

pref("browser.tabs.loadInBackground", false);

pref("browser.tabs.opentabfor.middleclick", false);

pref("browser.tabs.opentabfor.urlbar", false);

pref("browser.tabs.opentabfor.windowopen", false);

pref("browser.tabs.opentabfor.bookmarks", false);

pref("browser.tabs.warnOnClose", true);

// 0 = append, 1 = replace

pref("browser.tabs.loadGroup", 1);



// lets new tab/window load something different than first window

// -1 - use navigator startup preference

//  0 - loads blank page

//  1 - loads home page

//  2 - loads last page visited

pref("browser.tabs.loadOnNewTab", 0);

pref("browser.windows.loadOnNewWindow", 1);



// view source

pref("view_source.syntax_highlight", true);

pref("view_source.wrap_long_lines", false);



// dispatch left clicks only to content in browser (still allows clicks to chrome/xul)

pref("nglayout.events.dispatchLeftClickOnly", true);



// whether or not to use xbl form controls

pref("nglayout.debug.enable_xbl_forms", false);



// size of scrollbar snapping region

pref("slider.snapMultiplier", 6);



// option to choose plug-in finder

pref("application.use_ns_plugin_finder", false);



// Smart Browsing prefs

pref("browser.related.enabled", true);

pref("browser.related.autoload", 1);  // 0 = Always, 1 = After first use, 2 = Never

pref("browser.related.provider", "http://www-rl.netscape.com/wtgn?");

pref("browser.related.disabledForDomains", "");

pref("browser.goBrowsing.enabled", true);



// URI fixup prefs

pref("browser.fixup.alternate.enabled", true);

pref("browser.fixup.alternate.prefix", "www.");

pref("browser.fixup.alternate.suffix", ".com");



// Bookmarks prefs

pref("browser.bookmarks.confirm_sorting", true);



//Internet Search

pref("browser.search.defaultenginename", "chrome://communicator-region/locale/region.properties");



// Print header customization

// Use the following codes:

// &T - Title

// &U - Document URL

// &D - Date/Time

// &P - Page Number

// &PT - Page Number "of" Page total

// Set each header to a string containing zero or one of these codes

// and the code will be replaced in that string by the corresponding data

pref("print.print_headerleft", "&T");

pref("print.print_headercenter", "");

pref("print.print_headerright", "&U");

pref("print.print_footerleft", "&PT");

pref("print.print_footercenter", "");

pref("print.print_footerright", "&D");

pref("print.show_print_progress", true);



// When this is set to false it means each window has its PrintSettings

// and a change in one browser window does not effect the others

pref("print.use_global_printsettings", true);



// This indicates whether it should use the native dialog or the XP Dialog50

pref("print.use_native_print_dialog", false);



// Save the Printings after each print job

pref("print.save_print_settings", true);



pref("print.whileInPrintPreview", true);



// Cache old Presentation when going into Print Preview

pref("print.always_cache_old_pres", false);



// Enables you to specify the gap from the edge of the paper to the margin

// this is used by both Printing and Print Preview

pref("print.print_edge_top", 0); // 1/100 of an inch

pref("print.print_edge_left", 0); // 1/100 of an inch

pref("print.print_edge_right", 0); // 1/100 of an inch

pref("print.print_edge_bottom", 0); // 1/100 of an inch



// Default Capability Preferences: Security-Critical! 

// Editing these may create a security risk - be sure you know what you're doing

//pref("capability.policy.default.barprop.visible.set", "UniversalBrowserWrite");



pref("capability.policy.default_policynames", "mailnews");



pref("capability.policy.default.DOMException.code", "allAccess");

pref("capability.policy.default.DOMException.message", "allAccess");

pref("capability.policy.default.DOMException.name", "allAccess");

pref("capability.policy.default.DOMException.result", "allAccess");

pref("capability.policy.default.DOMException.toString", "allAccess");



pref("capability.policy.default.History.back", "allAccess");

pref("capability.policy.default.History.current", "UniversalBrowserRead");

pref("capability.policy.default.History.forward", "allAccess");

pref("capability.policy.default.History.go", "allAccess");

pref("capability.policy.default.History.item", "UniversalBrowserRead");

pref("capability.policy.default.History.next", "UniversalBrowserRead");

pref("capability.policy.default.History.previous", "UniversalBrowserRead");

pref("capability.policy.default.History.toString", "UniversalBrowserRead");



pref("capability.policy.default.HTMLDocument.close", "allAccess");

pref("capability.policy.default.HTMLDocument.open", "allAccess");



pref("capability.policy.default.Location.hash.set", "allAccess");

pref("capability.policy.default.Location.href.set", "allAccess");

pref("capability.policy.default.Location.reload", "allAccess");

pref("capability.policy.default.Location.replace", "allAccess");



pref("capability.policy.default.Navigator.preference", "allAccess");

pref("capability.policy.default.Navigator.preferenceinternal.get", "UniversalPreferencesRead");

pref("capability.policy.default.Navigator.preferenceinternal.set", "UniversalPreferencesWrite");



pref("capability.policy.default.Window.blur", "allAccess");

pref("capability.policy.default.Window.close", "allAccess");

pref("capability.policy.default.Window.closed", "allAccess");

pref("capability.policy.default.Window.Components", "allAccess");

pref("capability.policy.default.Window.document", "allAccess");

pref("capability.policy.default.Window.focus", "allAccess");

pref("capability.policy.default.Window.frames", "allAccess");

pref("capability.policy.default.Window.history", "allAccess");

pref("capability.policy.default.Window.length", "allAccess");

pref("capability.policy.default.Window.location", "allAccess");

pref("capability.policy.default.Window.opener", "allAccess");

pref("capability.policy.default.Window.parent", "allAccess");

pref("capability.policy.default.Window.self", "allAccess");

pref("capability.policy.default.Window.top", "allAccess");

pref("capability.policy.default.Window.window", "allAccess");



// Restrictions on the DOM for mail/news - see bugs 66938 and 84545

pref("capability.policy.mailnews.sites", "mailbox: imap: news:");



pref("capability.policy.mailnews.*.attributes.get", "noAccess");

pref("capability.policy.mailnews.*.baseURI.get", "noAccess");

pref("capability.policy.mailnews.*.data.get", "noAccess");

pref("capability.policy.mailnews.*.getAttribute", "noAccess");

pref("capability.policy.mailnews.*.getAttributeNS", "noAccess");

pref("capability.policy.mailnews.*.getNamedItem", "noAccess");

pref("capability.policy.mailnews.*.getNamedItemNS", "noAccess");

pref("capability.policy.mailnews.*.host.get", "noAccess");

pref("capability.policy.mailnews.*.hostname.get", "noAccess");

pref("capability.policy.mailnews.*.href.get", "noAccess");

pref("capability.policy.mailnews.*.innerHTML.get", "noAccess");

pref("capability.policy.mailnews.*.lowSrc.get", "noAccess");

pref("capability.policy.mailnews.*.nodeValue.get", "noAccess");

pref("capability.policy.mailnews.*.pathname.get", "noAccess");

pref("capability.policy.mailnews.*.protocol.get", "noAccess");

pref("capability.policy.mailnews.*.src.get", "noAccess");

pref("capability.policy.mailnews.*.substringData.get", "noAccess");

pref("capability.policy.mailnews.*.text.get", "noAccess");

pref("capability.policy.mailnews.*.title.get", "noAccess");

pref("capability.policy.mailnews.DOMException.toString", "noAccess");

pref("capability.policy.mailnews.HTMLAnchorElement.toString", "noAccess");

pref("capability.policy.mailnews.HTMLDocument.domain", "noAccess");

pref("capability.policy.mailnews.HTMLDocument.URL", "noAccess");

pref("capability.policy.mailnews.Location.toString", "noAccess");

pref("capability.policy.mailnews.Range.toString", "noAccess");

pref("capability.policy.mailnews.Window.blur", "noAccess");

pref("capability.policy.mailnews.Window.focus", "noAccess");

pref("capability.policy.mailnews.Window.innerWidth.set", "noAccess");

pref("capability.policy.mailnews.Window.innerHeight.set", "noAccess");

pref("capability.policy.mailnews.Window.moveBy", "noAccess");

pref("capability.policy.mailnews.Window.moveTo", "noAccess");

pref("capability.policy.mailnews.Window.name.set", "noAccess");

pref("capability.policy.mailnews.Window.outerHeight.set", "noAccess");

pref("capability.policy.mailnews.Window.outerWidth.set", "noAccess");

pref("capability.policy.mailnews.Window.resizeBy", "noAccess");

pref("capability.policy.mailnews.Window.resizeTo", "noAccess");

pref("capability.policy.mailnews.Window.screenX.set", "noAccess");

pref("capability.policy.mailnews.Window.screenY.set", "noAccess");

pref("capability.policy.mailnews.Window.sizeToContent", "noAccess");

pref("capability.policy.mailnews.document.load", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.channel", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.responseXML", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.responseText", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.status", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.statusText", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.abort", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.getAllResponseHeaders", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.getResponseHeader", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.open", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.send", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.setRequestHeader", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.readyState", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.overrideMimeType", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.onload", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.onerror", "noAccess");

pref("capability.policy.mailnews.XMLHttpRequest.onreadystatechange", "noAccess");

pref("capability.policy.mailnews.XMLSerializer.serializeToString", "noAccess");

pref("capability.policy.mailnews.XMLSerializer.serializeToStream", "noAccess");

pref("capability.policy.mailnews.DOMParser,parseFromString", "noAccess");

pref("capability.policy.mailnews.DOMParser,parseFromStream", "noAccess");

pref("capability.policy.mailnews.SOAPCall.transportURI", "noAccess");

pref("capability.policy.mailnews.SOAPCall.verifySourceHeader", "noAccess");

pref("capability.policy.mailnews.SOAPCall.invoke", "noAccess");

pref("capability.policy.mailnews.SOAPCall.asyncInvoke", "noAccess");

pref("capability.policy.mailnews.SOAPResponse.fault", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.styleURI", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.getAssociatedEncoding", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.setEncoder", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.getEncoder", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.setDecoder", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.setDecoder", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.getDecoder", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.defaultEncoder", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.defaultDecoder", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.schemaCollection", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.encode", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.decode", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.mapSchemaURI", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.unmapSchemaURI", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.getInternalSchemaURI", "noAccess");

pref("capability.policy.mailnews.SOAPEncoding.getExternalSchemaURI", "noAccess");

pref("capability.policy.mailnews.SOAPFault.element", "noAccess");

pref("capability.policy.mailnews.SOAPFault.faultNamespaceURI", "noAccess");

pref("capability.policy.mailnews.SOAPFault.faultCode", "noAccess");

pref("capability.policy.mailnews.SOAPFault.faultString", "noAccess");

pref("capability.policy.mailnews.SOAPFault.faultActor", "noAccess");

pref("capability.policy.mailnews.SOAPFault.detail", "noAccess");

pref("capability.policy.mailnews.SOAPHeaderBlock.actorURI", "noAccess");

pref("capability.policy.mailnews.SOAPHeaderBlock.mustUnderstand", "noAccess");

pref("capability.policy.mailnews.SOAPParameter", "noAccess");

pref("capability.policy.mailnews.SOAPPropertyBagMutator.propertyBag", "noAccess");

pref("capability.policy.mailnews.SOAPPropertyBagMutator.addProperty", "noAccess");

pref("capability.policy.mailnews.SchemaLoader.load", "noAccess");

pref("capability.policy.mailnews.SchemaLoader.loadAsync", "noAccess");

pref("capability.policy.mailnews.SchemaLoader.processSchemaElement", "noAccess");

pref("capability.policy.mailnews.SchemaLoader.onLoad", "noAccess");

pref("capability.policy.mailnews.SchemaLoader.onError", "noAccess");

pref("capability.policy.mailnews.WSDLLoader.load", "noAccess");

pref("capability.policy.mailnews.WSDLLoader.loadAsync", "noAccess");

pref("capability.policy.mailnews.WSDLLoader.onLoad", "noAccess");

pref("capability.policy.mailnews.WSDLLoader.onError", "noAccess");

pref("capability.policy.mailnews.WebServiceProxyFactory.createProxy", "noAccess");

pref("capability.policy.mailnews.WebServiceProxyFactory.createProxyAsync", "noAccess");

pref("capability.policy.mailnews.WebServiceProxyFactory.onLoad", "noAccess");

pref("capability.policy.mailnews.WebServiceProxyFactory.onError", "noAccess");



// XMLExtras

pref("capability.policy.default.XMLHttpRequest.channel", "noAccess");

pref("capability.policy.default.DOMParser.parseFromStream", "noAccess");



// Clipboard

pref("capability.policy.default.Clipboard.cutcopy", "noAccess");

pref("capability.policy.default.Clipboard.paste", "noAccess");



// Scripts & Windows prefs

pref("browser.block.target_new_window",     false);

pref("dom.disable_cookie_get",              false);

pref("dom.disable_cookie_set",              false);

pref("dom.disable_image_src_set",           false);

pref("dom.disable_window_flip",             false);

pref("dom.disable_window_move_resize",      false);

pref("dom.disable_window_status_change",    false);



pref("dom.disable_window_open_feature.titlebar",    false);

pref("dom.disable_window_open_feature.close",       false);

pref("dom.disable_window_open_feature.toolbar",     false);

pref("dom.disable_window_open_feature.location",    false);

pref("dom.disable_window_open_feature.directories", false);

pref("dom.disable_window_open_feature.personalbar", false);

pref("dom.disable_window_open_feature.menubar",     false);

pref("dom.disable_window_open_feature.scrollbars",  false);

pref("dom.disable_window_open_feature.resizable",   false);

pref("dom.disable_window_open_feature.minimizable", false);

pref("dom.disable_window_open_feature.status",      false);



pref("dom.allow_scripts_to_close_windows",          false);



pref("javascript.enabled",                  true);

pref("javascript.allow.mailnews",           false);

pref("javascript.options.strict",           false);

pref("javascript.options.showInConsole",    true);



// advanced prefs

pref("advanced.always_load_images",         true);

pref("security.enable_java",                true);

pref("advanced.mailftp",                    false);

pref("image.animation_mode",                "normal");



pref("offline.startup_state",            0);

pref("offline.send.unsent_messages",            0);

pref("offline.download.download_messages",  0);

pref("offline.prompt_synch_on_exit",            true);



// If there is ever a security firedrill that requires

// us to block certian ports global, this is the pref 

// to use.  Is is a comma delimited list of port numbers

// for example:

//   pref("network.security.ports.banned", "1,2,3,4,5");

// prevents necko connecting to ports 1-5 unless the protocol

// overrides.



// Prevent using external protocol handlers for these schemes

pref("network.protocol-handler.external.hcp", false);

pref("network.protocol-handler.external.vbscript", false);

pref("network.protocol-handler.external.javascript", false);

pref("network.protocol-handler.external.ms-help", false);

pref("network.protocol-handler.external.vnd.ms.radio", false);



pref("network.hosts.smtp_server",           "mail");

pref("network.hosts.pop_server",            "mail");

pref("network.protocols.useSystemDefaults",   false); // set to true if user links should use system default handlers



// <http>

pref("network.http.version", "1.1");	  // default

// pref("network.http.version", "1.0");   // uncomment this out in case of problems

// pref("network.http.version", "0.9");   // it'll work too if you're crazy

// keep-alive option is effectively obsolete. Nevertheless it'll work with

// some older 1.0 servers:



pref("network.http.proxy.version", "1.1");    // default

// pref("network.http.proxy.version", "1.0"); // uncomment this out in case of problems

                                              // (required if using junkbuster proxy)



// enable caching of http documents

pref("network.http.use-cache", true);



// this preference can be set to override the socket type used for normal

// HTTP traffic.  an empty value indicates the normal TCP/IP socket type.

pref("network.http.default-socket-type", "");



pref("network.http.keep-alive", true); // set it to false in case of problems

pref("network.http.proxy.keep-alive", true);

pref("network.http.keep-alive.timeout", 300);



// limit the absolute number of http connections.

pref("network.http.max-connections", 24);



// limit the absolute number of http connections that can be established per

// host.  if a http proxy server is enabled, then the "server" is the proxy

// server.  Otherwise, "server" is the http origin server.

pref("network.http.max-connections-per-server", 8);



// if network.http.keep-alive is true, and if NOT connecting via a proxy, then

// a new connection will only be attempted if the number of active persistent

// connections to the server is less then max-persistent-connections-per-server.

pref("network.http.max-persistent-connections-per-server", 2);



// if network.http.keep-alive is true, and if connecting via a proxy, then a

// new connection will only be attempted if the number of active persistent

// connections to the proxy is less then max-persistent-connections-per-proxy.

pref("network.http.max-persistent-connections-per-proxy", 4);



// amount of time (in seconds) to suspend pending requests, before spawning a

// new connection, once the limit on the number of persistent connections per

// host has been reached.  however, a new connection will not be created if

// max-connections or max-connections-per-server has also been reached.

pref("network.http.request.max-start-delay", 10);



// http specific network timeouts (XXX currently unused)

pref("network.http.connect.timeout",  30);	// in seconds

pref("network.http.request.timeout", 120);	// in seconds



// Headers

pref("network.http.accept.default", "text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,image/jpeg,image/gif;q=0.2,*/*;q=0.1");



pref("network.http.sendRefererHeader",      2); // 0=don't send any, 1=send only on clicks, 2=send on image requests as well



// Controls whether we send HTTPS referres to other HTTPS sites.

// By default this is enabled for compatibility (see bug 141641)

pref("network.http.sendSecureXSiteReferrer", true);



// Maximum number of consecutive redirects before aborting.

pref("network.http.redirection-limit", 20);



// Enable http compression: comment this out in case of problems with 1.1

// NOTE: support for "compress" has been disabled per bug 196406.

pref("network.http.accept-encoding" ,"gzip,deflate");



pref("network.http.pipelining"      , false);

pref("network.http.proxy.pipelining", false);



// Always pipeling the very first request:  this will only work when you are

// absolutely sure the the site or proxy you are browsing to/through support

// pipelining; the default behavior will be that the browser will first make

// a normal, non-pipelined request, then  examine  and remember the responce

// and only the subsequent requests to that site will be pipeline

pref("network.http.pipelining.firstrequest", false);



// Max number of requests in the pipeline

pref("network.http.pipelining.maxrequests" , 4);



pref("network.http.proxy.ssl.connect",true);

// </http>



// This preference controls whether or not internationalized domain names (IDN)

// are handled.  IDN requires a nsIIDNService implementation.

pref("network.enableIDN", true);



// This preference controls whether or not URLs with UTF-8 characters are

// escaped.  Set this preference to TRUE for strict RFC2396 conformance.

pref("network.standard-url.escape-utf8", true);



// Idle timeout for ftp control connections - 5 minute default

pref("network.ftp.idleConnectionTimeout", 300);



// directory listing format - constants are defined in nsIDirectoryListing.idl

// Do not set this to 0...

pref("network.dir.format", 2);



// enables the prefetch service (i.e., prefetching of <link rel="next"> URLs).

pref("network.prefetch-next", true);



// sspitzer:  change this back to "news" when we get to beta.

// for now, set this to news.mozilla.org because you can only

// post to the server specified by this pref.

pref("network.hosts.nntp_server",           "news.mozilla.org");



pref("network.hosts.socks_server",          "");

pref("network.hosts.socks_serverport",      1080);

pref("network.hosts.socks_conf",            "");

pref("network.image.imageBehavior",         0); // 0-Accept, 1-dontAcceptForeign, 2-dontUse

pref("network.image.warnAboutImages",       false);

pref("network.proxy.autoconfig_url",        "");

pref("network.proxy.type",                  0);

pref("network.proxy.ftp",                   "");

pref("network.proxy.ftp_port",              0);

pref("network.proxy.gopher",                "");

pref("network.proxy.gopher_port",           0);

pref("network.proxy.news",                  "");

pref("network.proxy.news_port",             0);

pref("network.proxy.http",                  "");

pref("network.proxy.http_port",             0);

pref("network.proxy.wais",                  "");

pref("network.proxy.wais_port",             0);

pref("network.proxy.ssl",                   "");

pref("network.proxy.ssl_port",              0);

pref("network.proxy.socks",                 "");

pref("network.proxy.socks_port",            0);

pref("network.proxy.socks_version",         5);

pref("network.proxy.no_proxies_on",         "localhost, 127.0.0.1");

pref("network.online",                      true); //online/offline

pref("network.cookie.cookieBehavior",       3); // 0-Accept, 1-dontAcceptForeign, 2-dontUse, 3-p3p

pref("network.cookie.disableCookieForMailNews", true); // disable all cookies for mail

pref("network.cookie.warnAboutCookies",     false);

pref("network.cookie.lifetime.enabled",     false);

pref("network.cookie.lifetime.behavior",    0);

pref("network.cookie.lifetime.days",        90);



// The following default value is for p3p medium mode.

// See extensions/cookie/resources/content/p3p.xul for the definitions of low/medium/hi

pref("network.cookie.p3p",                  "ffffaaaa");

pref("network.cookie.p3plevel",             1); // 0=low, 1=medium, 2=high, 3=custom



pref("signon.rememberSignons",              true);

pref("signon.expireMasterPassword",         false);

pref("network.enablePad",                   false); // Allow client to do proxy autodiscovery

pref("network.enableIDN",                   false); // Turn on/off IDN (Internationalized Domain Name) resolution

pref("converter.html2txt.structs",          true); // Output structured phrases (strong, em, code, sub, sup, b, i, u)

pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention

pref("wallet.captureForms",                 true);

pref("wallet.notified",                     false);

pref("wallet.TutorialFromMenu",             "chrome://navigator/locale/navigator.properties");

pref("wallet.Server",                       "chrome://navigator/locale/navigator.properties");

pref("wallet.Samples",                      "chrome://navigator/locale/navigator.properties");

pref("wallet.version",                      "1");

pref("wallet.enabled",                      true);

pref("wallet.crypto",                       false);

pref("wallet.crypto.autocompleteoverride",  false); // Ignore 'autocomplete=off' - available only when wallet.crypto is enabled. 

pref("wallet.namePanel.hide",               false);

pref("wallet.addressPanel.hide",            false);

pref("wallet.phonePanel.hide",              false);

pref("wallet.creditPanel.hide",             false);

pref("wallet.employPanel.hide",             false);

pref("wallet.miscPanel.hide",               false);

pref("imageblocker.enabled",                true);

pref("intl.accept_languages",               "chrome://navigator/locale/navigator.properties");

pref("intl.accept_charsets",                "iso-8859-1,*,utf-8");

pref("intl.collationOption",                "chrome://navigator-platform/locale/navigator.properties");

pref("intl.menuitems.alwaysappendaccesskeys","chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.browser.static",     "chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.browser.more1",      "chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.browser.more2",      "chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.browser.more3",      "chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.browser.more4",      "chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.browser.more5",      "chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.mailedit",           "chrome://navigator/locale/navigator.properties");

pref("intl.charsetmenu.browser.cache",      "");

pref("intl.charsetmenu.mailview.cache",     "");

pref("intl.charsetmenu.composer.cache",     "");

pref("intl.charsetmenu.browser.cache.size", 5);

pref("intl.charset.detector",               "chrome://navigator/locale/navigator.properties");

pref("intl.charset.default",                "chrome://navigator-platform/locale/navigator.properties");

pref("intl.content.langcode",               "chrome://communicator-region/locale/region.properties");

pref("intl.locale.matchOS",                 false);

// fallback charset list for Unicode conversion (converting from Unicode)

// currently used for mail send only to handle symbol characters (e.g Euro, trademark, smartquotes)

// for ISO-8859-1

pref("intl.fallbackCharsetList.ISO-8859-1", "windows-1252");

pref("font.language.group",                 "chrome://navigator/locale/navigator.properties");



// -- folders (Mac: these are binary aliases.)

pref("mail.signature_file",             "");

pref("mail.directory",                  "");



pref("images.dither", "auto");

pref("news.directory",                  "");

pref("security.directory",              "");



pref("autoupdate.enabled",              true);



pref("browser.editor.disabled", false);



pref("spellchecker.dictionary", "");



pref("signed.applets.codebase_principal_support", false);

pref("security.checkloaduri", true);

pref("security.xpconnect.plugin.unrestricted", true);



// Modifier key prefs: default to Windows settings,

// menu access key = alt, accelerator key = control.

// Use 17 for Ctrl, 18 for Alt, 224 for Meta, 0 for none. Mac settings in macprefs.js

pref("ui.key.accelKey", 17);

pref("ui.key.generalAccessKey", 18);

pref("ui.key.menuAccessKey", 18);

pref("ui.key.menuAccessKeyFocuses", false);

pref("ui.key.saveLink.shift", true); // true = shift, false = meta



// Middle-mouse handling

pref("middlemouse.paste", false);

pref("middlemouse.openNewWindow", true);

pref("middlemouse.contentLoadURL", false);

pref("middlemouse.scrollbarPosition", false);



// Clipboard behavior

pref("clipboard.autocopy", false);



// 0=lines, 1=pages, 2=history , 3=text size

pref("mousewheel.withnokey.action",0);

pref("mousewheel.withnokey.numlines",1);	

pref("mousewheel.withnokey.sysnumlines",true);

pref("mousewheel.withcontrolkey.action",0);

pref("mousewheel.withcontrolkey.numlines",1);

pref("mousewheel.withcontrolkey.sysnumlines",true);

pref("mousewheel.withshiftkey.action",0);

pref("mousewheel.withshiftkey.numlines",1);

pref("mousewheel.withshiftkey.sysnumlines",false);

pref("mousewheel.withaltkey.action",2);

pref("mousewheel.withaltkey.numlines",1);

pref("mousewheel.withaltkey.sysnumlines",false);



pref("profile.confirm_automigration",true);



// the amount of time (in seconds) that must elapse

// before we think your mozilla profile is defunct

// and you'd benefit from re-migrating from 4.x

// see bug #137886 for more details

//

// if -1, we never think your profile is defunct

// and users will never see the remigrate UI.

pref("profile.seconds_until_defunct", -1);

// We can show it anytime from menus

pref("profile.manage_only_at_launch", false);



// Customizable toolbar stuff

pref("custtoolbar.personal_toolbar_folder", "");



pref("sidebar.customize.all_panels.url", "http://sidebar.ru/panels.rdf");

pref("sidebar.customize.directory.url", "http://sidebar.ru/");

pref("sidebar.customize.more_panels.url", "http://sidebar.ru/");

pref("sidebar.num_tabs_in_view", 8);



pref("prefs.converted-to-utf8",false);

// --------------------------------------------------

// IBMBIDI 

// --------------------------------------------------

//

// ------------------

//  Text Direction

// ------------------

// 1 = directionLTRBidi *

// 2 = directionRTLBidi

pref("bidi.direction", 1);

// ------------------

//  Text Type

// ------------------

// 1 = charsettexttypeBidi *

// 2 = logicaltexttypeBidi

// 3 = visualtexttypeBidi

pref("bidi.texttype", 1);

// ------------------

//  Controls Text Mode

// ------------------

// 1 = logicalcontrolstextmodeBidiCmd

// 2 = visualcontrolstextmodeBidi <-- NO LONGER SUPPORTED

// 3 = containercontrolstextmodeBidi *

pref("bidi.controlstextmode", 1);

// ------------------

//  Clipboard Text Mode

// ------------------

//  1 = logicalclipboardtextmodeBidi

// 2 = visiualclipboardtextmodeBidi

// 3 = sourceclipboardtextmodeBidi *

pref("bidi.clipboardtextmode", 3);

// ------------------

//  Numeral Style

// ------------------

// 0 = nominalnumeralBidi *

// 1 = regularcontextnumeralBidi

// 2 = hindicontextnumeralBidi

// 3 = arabicnumeralBidi

// 4 = hindinumeralBidi

pref("bidi.numeral", 0);

// ------------------

//  Support Mode

// ------------------

// 1 = mozillaBidisupport *

// 2 = OsBidisupport

// 3 = disableBidisupport

pref("bidi.support", 1);

// ------------------

//  Charset Mode

// ------------------

// 1 = doccharactersetBidi *

// 2 = defaultcharactersetBidi

pref("bidi.characterset", 1);





pref("browser.throbber.url","chrome://navigator-region/locale/region.properties");



// used for double-click word selection behavior. Win will override.

pref("layout.word_select.eat_space_to_next_word", false);

pref("layout.word_select.stop_at_punctuation", true);



// pref to force frames to be resizable

pref("layout.frames.force_resizability", false);



// pref to permit users to make verified SOAP calls by default

pref("capability.policy.default.SOAPCall.invokeVerifySourceHeader", "allAccess");



// pref to control the alert notification 

pref("alerts.slideIncrement", 1);

pref("alerts.slideIncrementTime", 10);

pref("alerts.totalOpenTime", 4000);

pref("alerts.height", 50);



// update notifications prefs

pref("update_notifications.enabled", true);

pref("update_notifications.provider.0.frequency", 7); // number of days

pref("update_notifications.provider.0.datasource", "chrome://communicator-region/locale/region.properties");



// 0 opens the download manager

// 1 opens a progress dialog

// 2 and other values, no download manager, no progress dialog. 

pref("browser.downloadmanager.behavior", 0);



// if true, allow plug-ins to override internal imglib decoder mime types in full-page mode

pref("plugin.override_internal_types", false);

pref("plugin.expose_full_path", false); // if true navigator.plugins reveals full path



// See bug 136985.  Gives embedders a pref to hook into to show

// a popup blocker if they choose.

pref("browser.popups.showPopupBlocker", true);



// Pref to control whether the viewmanager code does double-buffering or not

// See http://bugzilla.mozilla.org/show_bug.cgi?id=169483 for further details...

pref("viewmanager.do_doublebuffering", true);



pref("dom.disable_open_during_load",              false);

pref("privacy.popups.first_popup",                true);

pref("privacy.popups.sound_enabled",              false);

pref("privacy.popups.sound_url",                  "");

pref("privacy.popups.statusbar_icon_enabled",     true);

pref("privacy.popups.prefill_whitelist",          false);

pref("privacy.popups.remove_blacklist",           true);



// whether use prefs from system

pref("config.use_system_prefs", false);



// if the system has enabled accessibility

pref("config.use_system_prefs.accessibility", false);



